@@ -11,11 +11,9 @@ try:
     from IPython.display import display as ipy_display
 except ImportError:
     pass
-from matplotlib import __version__ as mpl_version
 from matplotlib import get_backend
 from matplotlib.pyplot import axes, gca, gcf, figure
 from numpy.distutils.misc_util import is_sequence
-from packaging import version
 
 from .utils import ioff
 
@@ -471,6 +469,31 @@ def create_mpl_selection_slider(ax, label, values, slider_format_string):
     return slider
 
 
+def process_mpl_widget(val, update):
+    """
+    handle the case of a kwarg being an existing matplotlib widget.
+    This needs to be separate so that the controller can call it when mixing ipywidets and
+    a widget like scatter_selector without having to create a control figure
+    """
+    if isinstance(val, mwidgets.RadioButtons):
+        # gotta set it to the zeroth index bc theres no reasonable way to determine the current value
+        # the only way the current value is stored is through the color of the circles.
+        # so could query that an extract but oh boy do I ever not want to
+        val.set_active(0)
+        cb = val.on_clicked(partial(changeify_radio, labels=val.labels, update=update))
+        return val.labels[0], val, cb
+    elif isinstance(val, mwidgets.Slider):
+        # potential future improvement:
+        # check if valstep has been set and then try to infer the values
+        # but not now, I'm trying to avoid premature optimization lest this
+        # drag on forever
+        cb = val.on_changed(partial(changeify, update=partial(update, values=None)))
+        return val.val, val, cb
+    else:
+        cb = val.on_changed(partial(changeify, update=partial(update, values=None)))
+        return val.val, val, cb
+
+
 def kwarg_to_mpl_widget(
     fig,
     heights,
@@ -521,20 +544,9 @@ def kwarg_to_mpl_widget(
         radio_buttons = mwidgets.RadioButtons(radio_ax, val, active=0)
         cb = radio_buttons.on_clicked(partial(changeify_radio, labels=val, update=update))
         return val[0], radio_buttons, cb, widget_y
-    elif isinstance(val, mwidgets.RadioButtons):
-        # gotta set it to the zeroth index bc theres no reasonable way to determine the current value
-        # the only way the current value is stored is through the color of the circles.
-        # so could query that an extract but oh boy do I ever not want to
-        val.set_active(0)
-        cb = val.on_clicked(partial(changeify_radio, labels=val.labels, update=update))
-        return val.labels[0], val, cb, widget_y
-    elif isinstance(val, mwidgets.Slider):
-        # potential future improvement:
-        # check if valstep has been set and then try to infer the values
-        # but not now, I'm trying to avoid premature optimization lest this
-        # drag on forever
-        cb = val.on_changed(partial(changeify, update=partial(update, values=None)))
-        return val.val, val, cb, widget_y
+    elif isinstance(val, mwidgets.AxesWidget):
+        val, widget, cb = process_mpl_widget(val, update)
+        return val, widget, cb, widget_y
     else:
         slider = None
         update_fxn = None
